
#ifndef _C12_ki561_
#define _C12_ki561_

#ifdef __cplusplus
extern "C" {
#endif

extern void F1244_11844(EIF_REFERENCE, EIF_REFERENCE);
extern void F1244_11845(EIF_REFERENCE);
extern void EIF_Minit561(void);
extern char *(*R9503[])();
extern char *(*R9523[])();

#ifdef __cplusplus
}
#endif

#endif
